==> com.liferay.frontend.taglib-2.2.8.jar: META-INF/resources/sidebar_panel/js/sidebar_panel.js <==
AUI.add(
	'liferay-sidebar-panel',
	function(A) {
		var Lang = A.Lang;

		var SidebarPanel = A.Component.create(
			{
				ATTRS: {
					resourceUrl: {
						validator: Lang.isString
					},

					searchContainerId: {
						validator: Lang.isString
					},

					targetNode: {
						setter: A.one
					}
				},

				AUGMENTS: [Liferay.PortletBase],

				EXTENDS: A.Base,

				NAME: 'liferaysidebarpanel',

				prototype: {
					initializer: function(config) {
						var instance = this;

						instance._searchContainerRegisterHandle = Liferay.on('search-container:registered', instance._onSearchContainerRegistered, instance);
					},

					destructor: function() {
						var instance = this;

						instance._detachSearchContainerRegisterHandle();

						(new A.EventHandle(instance._eventHandles)).detach();
					},

					_bindUI: function() {
						var instance = this;

						instance._eventHandles = [
							instance._searchContainer.on('rowToggled', instance._onRowToggled, instance)
						];
					},

					_detachSearchContainerRegisterHandle: function() {
						var instance = this;

						var searchContainerRegisterHandle = instance._searchContainerRegisterHandle;

						if (searchContainerRegisterHandle) {
							searchContainerRegisterHandle.detach();

							instance._searchContainerRegisterHandle = null;
						}
					},

					_onRowToggled: function(event) {
						var instance = this;

						A.io.request(
							instance.get('resourceUrl'),
							{
								form: instance._searchContainer.getForm().getDOM(),
								on: {
									success: function(event, id, xhr) {
										var response = xhr.responseText;

										instance.get('targetNode').setContent(response);
									}
								}
							}
						);
					},

					_onSearchContainerRegistered: function(event) {
						var instance = this;

						var searchContainer = event.searchContainer;

						if (searchContainer.get('id') === instance.get('searchContainerId')) {
							instance._searchContainer = searchContainer;

							instance._detachSearchContainerRegisterHandle();

							instance.get('targetNode').plug(A.Plugin.ParseContent);

							instance._bindUI();
						}
					}
				}
			}
		);

		Liferay.SidebarPanel = SidebarPanel;
	},
	'',
	{
		requires: ['aui-base', 'aui-io-request', 'aui-parse-content', 'liferay-portlet-base']
	}
);

==> com.liferay.frontend.taglib-3.1.2.jar: META-INF/resources/sidebar_panel/js/sidebar_panel.js <==
AUI.add(
	'liferay-sidebar-panel',
	function(A) {
		var Lang = A.Lang;

		var SidebarPanel = A.Component.create(
			{
				ATTRS: {
					resourceUrl: {
						validator: Lang.isString
					},

					searchContainerId: {
						validator: Lang.isString
					},

					targetNode: {
						setter: A.one
					}
				},

				AUGMENTS: [Liferay.PortletBase],

				EXTENDS: A.Base,

				NAME: 'liferaysidebarpanel',

				prototype: {
					initializer: function(config) {
						var instance = this;

						instance._searchContainerRegisterHandle = Liferay.on('search-container:registered', instance._onSearchContainerRegistered, instance);
					},

					destructor: function() {
						var instance = this;

						instance._detachSearchContainerRegisterHandle();

						(new A.EventHandle(instance._eventHandles)).detach();
					},

					_bindUI: function() {
						var instance = this;

						instance._eventHandles = [
							instance._searchContainer.on(
								'rowToggled',
								A.debounce(instance._onRowToggled, 50, instance),
								instance
							)
						];
					},

					_detachSearchContainerRegisterHandle: function() {
						var instance = this;

						var searchContainerRegisterHandle = instance._searchContainerRegisterHandle;

						if (searchContainerRegisterHandle) {
							searchContainerRegisterHandle.detach();

							instance._searchContainerRegisterHandle = null;
						}
					},

					_onRowToggled: function(event) {
						var instance = this;

						A.io.request(
							instance.get('resourceUrl'),
							{
								form: instance._searchContainer.getForm().getDOM(),
								on: {
									success: function(event, id, xhr) {
										var response = xhr.responseText;

										instance.get('targetNode').setContent(response);
									}
								}
							}
						);
					},

					_onSearchContainerRegistered: function(event) {
						var instance = this;

						var searchContainer = event.searchContainer;

						if (searchContainer.get('id') === instance.get('searchContainerId')) {
							instance._searchContainer = searchContainer;

							instance._detachSearchContainerRegisterHandle();

							instance.get('targetNode').plug(A.Plugin.ParseContent);

							instance._bindUI();
						}
					}
				}
			}
		);

		Liferay.SidebarPanel = SidebarPanel;
	},
	'',
	{
		requires: ['aui-base', 'aui-debounce', 'aui-io-request', 'aui-parse-content', 'liferay-portlet-base']
	}
);
